@@ -10,7 +10,7 @@ use DBI;
 
 use base qw(Alzabo::Driver);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.35 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.36 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -142,6 +142,11 @@ sub driver_id
     return 'MySQL';
 }
 
+sub dbi_driver_name
+{
+    return 'mysql';
+}
+
 __END__
 
 =head1 NAME
