@@ -8,7 +8,7 @@ use DBD::Pg;
 
 use base qw(Alzabo::Driver);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -115,6 +115,11 @@ sub driver_id
     return 'PostgreSQL';
 }
 
+sub dbi_driver_name
+{
+    return 'Pg';
+}
+
 __END__
 
 =head1 NAME
